@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_VALIDATION_COMBO_H_
 # define _GNM_VALIDATION_COMBO_H_
 
-#include "gnm-cell-combo.h"
+#include <gnm-cell-combo.h>
 
 G_BEGIN_DECLS
 
